==> ZenTaoPMS.17.2.php5.4_5.6.zip: zentaopms/module/repo/lang/vi.php <==
<?php
$lang->repo->common          = 'Repo';
$lang->repo->browse          = 'Xem';
$lang->repo->viewRevision    = 'Xem Revision';
$lang->repo->product         = 'Product';
$lang->repo->execution       = $lang->execution->common;
$lang->repo->create          = 'Tạo';
$lang->repo->maintain        = 'Repo danh sách';
$lang->repo->edit            = 'Sửa';
$lang->repo->delete          = 'Xóa Repo';
$lang->repo->showSyncCommit  = 'Display Sync';
$lang->repo->ajaxSyncCommit  = 'Interface: Ajax Sync Note';
$lang->repo->setRules        = 'Thiết lập quy định';
$lang->repo->download        = 'Tải về File';
$lang->repo->downloadDiff    = 'Tải về Diff';
$lang->repo->addBug          = 'Thêm duyệt';
$lang->repo->editBug         = 'Sửa Bug';
$lang->repo->deleteBug       = 'Xóa Bug';
$lang->repo->addComment      = 'Thêm nhận xét';
$lang->repo->editComment     = 'Sửa nhận xét';
$lang->repo->deleteComment   = 'Xóa nhận xét';
$lang->repo->encrypt         = 'Encrypt';
$lang->repo->repo            = 'Repository';
$lang->repo->parent          = 'Parent File';
$lang->repo->branch          = 'Branch';
$lang->repo->tag             = 'Tag';
$lang->repo->addWebHook      = 'Add Webhook';
$lang->repo->apiGetRepoByUrl = 'API: Get repo by URL';

$lang->repo->submit     = 'Gửi';
$lang->repo->cancel     = 'Hủy';
$lang->repo->addComment = 'Thêm nhận xét';

$lang->repo->module   = 'Module';
$lang->repo->type     = 'Loại';
$lang->repo->assign   = 'Giao cho';
$lang->repo->title    = 'Tiêu đề';
$lang->repo->detile   = 'Chi tiết';
$lang->repo->lines    = 'Dòng';
$lang->repo->line     = 'Dòng';
$lang->repo->expand   = 'Mở ra';
$lang->repo->collapse = 'Gấp lại';

$lang->repo->id        = 'ID';
$lang->repo->SCM       = 'Loại';
$lang->repo->name      = 'Tên';
$lang->repo->path      = 'Đường dẫn';
$lang->repo->prefix    = 'Prefix';
$lang->repo->config    = 'Cấu hình';
$lang->repo->desc      = 'Mô tả';
$lang->repo->account   = 'Người dùng';
$lang->repo->password  = 'Mật khẩu';
$lang->repo->encoding  = 'Encoding';
$lang->repo->client    = 'Client Path';
$lang->repo->size      = 'Size';
$lang->repo->revision  = 'Revision';
$lang->repo->revisionA = 'Revision';
$lang->repo->revisions = 'Revision';
$lang->repo->time      = 'Ngày';
$lang->repo->committer = 'Committer';
$lang->repo->commits   = 'Commits';
$lang->repo->synced    = 'Khởi tạo đồng bộ';
$lang->repo->lastSync  = 'Last Sync';
$lang->repo->deleted   = 'Đã xóa';
$lang->repo->commit    = 'Giao phó';
$lang->repo->comment   = 'Nhận xét';
$lang->repo->view      = 'Xem File';
$lang->repo->viewA     = 'Xem';
$lang->repo->log       = 'Revision nhật ký';
$lang->repo->blame     = 'Blame';
$lang->repo->date      = 'Ngày';
$lang->repo->diff      = 'Diff';
$lang->repo->diffAB    = 'Diff';
$lang->repo->diffAll   = 'Diff tất cả';
$lang->repo->viewDiff  = 'Xem diff';
$lang->repo->allLog    = 'Tất cả Revisions';
$lang->repo->location  = 'Vị trí';
$lang->repo->file      = 'File';
$lang->repo->action    = 'Hành động';
$lang->repo->code      = 'Mã';
$lang->repo->review    = 'Repo duyệt';
$lang->repo->acl       = 'Phân quyền';
$lang->repo->group     = 'Nhóm';
$lang->repo->user      = 'Người dùng';
$lang->repo->info      = 'Thông tin phiên bản';

$lang->repo->title      = 'Tiêu đề';
$lang->repo->status     = 'Tình trạng';
$lang->repo->openedBy   = 'Người tạo';
$lang->repo->assignedTo = 'Giao cho';
$lang->repo->openedDate = 'Ngày tạo';

$lang->repo->latestRevision = 'Latest Revision';
$lang->repo->actionInfo     = "Thêm bởi %s trong %s";
$lang->repo->changes        = "Thay đổi nhật ký";
$lang->repo->reviewLocation = "File: %s@%s, Line: %s - %s";
$lang->repo->commentEdit    = '<i class="icon-pencil"></i>';
$lang->repo->commentDelete  = '<i class="icon-remove"></i>';
$lang->repo->allChanges     = "Thay đổi khác";
$lang->repo->commitTitle    = "The %sth Commit";
$lang->repo->mark           = "Mark Tag";
$lang->repo->split          = "Split Mark";

$lang->repo->objectRule   = 'Object quy tắc';
$lang->repo->objectIdRule = 'Object ID quy tắc';
$lang->repo->actionRule   = 'Action quy tắc';
$lang->repo->manHourRule  = 'Man-hour quy tắc';
$lang->repo->ruleUnit     = "Unit";
$lang->repo->ruleSplit    = "Multiple keywords are divided by ';'. For example: task multiple keywords: Task;task";

$lang->repo->viewDiffList['inline'] = 'Inline';
$lang->repo->viewDiffList['appose'] = 'Parallel';

$lang->repo->encryptList['plain']  = 'Không có encryption';
$lang->repo->encryptList['base64'] = 'BASE64';

$lang->repo->logStyles['A'] = 'Thêm';
$lang->repo->logStyles['M'] = 'Sửa';
$lang->repo->logStyles['D'] = 'Xóa';

$lang->repo->encodingList['utf_8'] = 'UTF-8';
$lang->repo->encodingList['gbk']   = 'GBK';

$lang->repo->scmList['Git']        = 'Git';
$lang->repo->scmList['Subversion'] = 'SVN';

$lang->repo->notice = new stdclass();
$lang->repo->notice->syncing        = 'Đang đồng bộ. Vui lòng đợi ...';
$lang->repo->notice->syncComplete   = 'Synchronized. Now redirecting ...';
$lang->repo->notice->syncedCount    = 'The number of records synchronized is ';
$lang->repo->notice->delete         = 'Bạn có muốn xóa this repo?';
$lang->repo->notice->successDelete  = 'Repository is removed.';
$lang->repo->notice->commentContent = 'Nhận xét';
$lang->repo->notice->deleteBug      = 'Bạn có muốn xóa bug này?';
$lang->repo->notice->deleteComment  = 'Bạn có muốn xóa this comment?';
$lang->repo->notice->lastSyncTime   = 'Last Sync:';

$lang->repo->rules = new stdclass();
$lang->repo->rules->exampleLabel = "Comment Example";
$lang->repo->rules->example['task']['start']  = "%start% %task% %id%1%split%2 %cost%%consumedmark%1%cunit% %left%%leftmark%3%lunit%";
$lang->repo->rules->example['task']['finish'] = "%finish% %task% %id%1%split%2 %cost%%consumedmark%10%cunit%";
$lang->repo->rules->example['task']['effort'] = "%effort% %task% %id%1%split%2 %cost%%consumedmark%1%cunit% %left%%leftmark%3%lunit%";
$lang->repo->rules->example['bug']['resolve'] = "%resolve% %bug% %id%1%split%2";

$lang->repo->error = new stdclass();
$lang->repo->error->useless       = 'Your server disabled exec and shell_exec, so it cannot be applied.';
$lang->repo->error->connect       = 'Connection to the repo failed. Vui lòng enter username, password and repo address correctly!';
$lang->repo->error->version       = 'Phiên bản 1.8+ of https and svn protocol là bắt buộc. Vui lòng update to latest version! Go to http://subversion.apache.org/';
$lang->repo->error->path          = 'Repo address is the file path, ví dụ:  /home/test.';
$lang->repo->error->cmd           = 'Client Error!';
$lang->repo->error->diff          = 'Two versions phải là selected.';
$lang->repo->error->safe          = 'For security reasons, the client version needs to be detected. Please write the version to the file %s. <br /> Execute command: %s';
$lang->repo->error->product       = "Please select {$lang->productCommon}!";
$lang->repo->error->commentText   = 'Vui lòng nhập nội dung để duyệt!';
$lang->repo->error->comment       = 'Vui lòng nhập content!';
$lang->repo->error->title         = 'Vui lòng nhập title!';
$lang->repo->error->accessDenied  = 'You do not have the privilege to access the repository.';
$lang->repo->error->noFound       = 'The repo không là found.';
$lang->repo->error->noFile        = '%s không tồn tại.';
$lang->repo->error->noPriv        = 'The program does not have the privilege  to switch to %s';
$lang->repo->error->output        = "The command is: %s\nThe error is(%s): %s\n";
$lang->repo->error->clientVersion = "Client version is too low, please upgrade or change SVN client";
$lang->repo->error->encoding      = "The encoding maybe wrong. Vui lòng change the encoding and try again.";
$lang->repo->error->deleted       = "Deletion of the repository failed. The current repository has a commit record associated with the design.";
$lang->repo->error->clientPath    = "The client installation directory cannot have spaces!";

$lang->repo->syncTips      = '<strong>Bạn có thể tìm tham khảo làm sao thiết lập đồng bộ Git từ <a target="_blank" href="https://www.zentao.pm/book/zentaomanual/free-open-source-project-management-software-git-105.html">here</a>.</strong>';
$lang->repo->encodingsTips = "The encodings of commit comments, can be comma separated values，ví dụ:  utf-8";

$lang->repo->example              = new stdclass();
$lang->repo->example->client      = new stdclass();
$lang->repo->example->path        = new stdclass();
$lang->repo->example->client->git = "ví dụ:  /usr/bin/git";
$lang->repo->example->client->svn = "ví dụ:  /usr/bin/svn";
$lang->repo->example->path->git   = "ví dụ:  /home/user/myproject";
$lang->repo->example->path->svn   = "ví dụ:  http://example.googlecode.com/svn/trunk/myproject";
$lang->repo->example->config      = "Config directory là bắt buộc in https. Sử dụng '--config-dir' to generate config dir.";
$lang->repo->example->encoding    = "input encoding of files";

$lang->repo->typeList['standard']    = 'Tiêu chuẩn';
$lang->repo->typeList['performance'] = 'Hiệu suất';
$lang->repo->typeList['security']    = 'Bảo mật';
$lang->repo->typeList['redundancy']  = 'Redundancy';
$lang->repo->typeList['logicError']  = 'Logic Error';

==> ZenTaoPMS.17.5.php8.0.zip: zentaopms/module/repo/lang/vi.php <==
<?php
$lang->repo->common          = 'Repo';
$lang->repo->browse          = 'Xem';
$lang->repo->viewRevision    = 'Xem Revision';
$lang->repo->product         = 'Product';
$lang->repo->execution       = $lang->execution->common;
$lang->repo->create          = 'Tạo';
$lang->repo->maintain        = 'Repo danh sách';
$lang->repo->edit            = 'Sửa';
$lang->repo->delete          = 'Xóa Repo';
$lang->repo->showSyncCommit  = 'Display Sync';
$lang->repo->ajaxSyncCommit  = 'Interface: Ajax Sync Note';
$lang->repo->setRules        = 'Thiết lập quy định';
$lang->repo->download        = 'Tải về File';
$lang->repo->downloadDiff    = 'Tải về Diff';
$lang->repo->addBug          = 'Thêm duyệt';
$lang->repo->editBug         = 'Sửa Bug';
$lang->repo->deleteBug       = 'Xóa Bug';
$lang->repo->addComment      = 'Thêm nhận xét';
$lang->repo->editComment     = 'Sửa nhận xét';
$lang->repo->deleteComment   = 'Xóa nhận xét';
$lang->repo->encrypt         = 'Encrypt';
$lang->repo->repo            = 'Repository';
$lang->repo->parent          = 'Parent File';
$lang->repo->branch          = 'Branch';
$lang->repo->tag             = 'Tag';
$lang->repo->addWebHook      = 'Add Webhook';
$lang->repo->apiGetRepoByUrl = 'API: Get repo by URL';

$lang->repo->browseAction    = 'Browse Repo';
$lang->repo->createAction    = 'Create Repo';
$lang->repo->editAction      = 'Edit Repo';
$lang->repo->diffAction      = 'Diff Revision';
$lang->repo->downloadAction  = 'Download File';
$lang->repo->revisionAction  = 'Revision Detail';
$lang->repo->blameAction     = 'Blame';
$lang->repo->reviewAction    = 'Review List';
$lang->repo->downloadCode    = 'Download Code';
$lang->repo->downloadZip     = 'Download compressed package';
$lang->repo->sshClone        = 'Clone with SSH';
$lang->repo->httpClone       = 'Clone with HTTP';
$lang->repo->cloneUrl        = 'Clone URL';

$lang->repo->submit     = 'Gửi';
$lang->repo->cancel     = 'Hủy';
$lang->repo->addComment = 'Thêm nhận xét';

$lang->repo->copy     = 'Click to copy';
$lang->repo->copied   = 'Copy successful';
$lang->repo->module   = 'Module';
$lang->repo->type     = 'Loại';
$lang->repo->assign   = 'Giao cho';
$lang->repo->title    = 'Tiêu đề';
$lang->repo->detile   = 'Chi tiết';
$lang->repo->lines    = 'Dòng';
$lang->repo->line     = 'Dòng';
$lang->repo->expand   = 'Mở ra';
$lang->repo->collapse = 'Gấp lại';

$lang->repo->id                 = 'ID';
$lang->repo->SCM                = 'Loại';
$lang->repo->name               = 'Tên';
$lang->repo->path               = 'Đường dẫn';
$lang->repo->prefix             = 'Prefix';
$lang->repo->config             = 'Cấu hình';
$lang->repo->desc               = 'Mô tả';
$lang->repo->account            = 'Người dùng';
$lang->repo->password           = 'Mật khẩu';
$lang->repo->encoding           = 'Encoding';
$lang->repo->client             = 'Client Path';
$lang->repo->size               = 'Size';
$lang->repo->revision           = 'Revision';
$lang->repo->revisionA          = 'Revision';
$lang->repo->revisions          = 'Revision';
$lang->repo->time               = 'Ngày';
$lang->repo->committer          = 'Committer';
$lang->repo->commits            = 'Commits';
$lang->repo->synced             = 'Khởi tạo đồng bộ';
$lang->repo->lastSync           = 'Last Sync';
$lang->repo->deleted            = 'Đã xóa';
$lang->repo->commit             = 'Giao phó';
$lang->repo->comment            = 'Nhận xét';
$lang->repo->view               = 'Xem File';
$lang->repo->viewA              = 'Xem';
$lang->repo->log                = 'Revision nhật ký';
$lang->repo->blame              = 'Blame';
$lang->repo->date               = 'Ngày';
$lang->repo->diff               = 'Diff';
$lang->repo->diffAB             = 'Diff';
$lang->repo->diffAll            = 'Diff tất cả';
$lang->repo->viewDiff           = 'Xem diff';
$lang->repo->allLog             = 'Tất cả Revisions';
$lang->repo->location           = 'Vị trí';
$lang->repo->file               = 'File';
$lang->repo->action             = 'Hành động';
$lang->repo->code               = 'Mã';
$lang->repo->review             = 'Repo duyệt';
$lang->repo->acl                = 'Phân quyền';
$lang->repo->group              = 'Nhóm';
$lang->repo->user               = 'Người dùng';
$lang->repo->info               = 'Thông tin phiên bản';
$lang->repo->job                = 'Job';
$lang->repo->fileServerUrl      = 'File Server Url';
$lang->repo->fileServerAccount  = 'File Server Account';
$lang->repo->fileServerPassword = 'File Server Password';

$lang->repo->title      = 'Tiêu đề';
$lang->repo->status     = 'Tình trạng';
$lang->repo->openedBy   = 'Người tạo';
$lang->repo->assignedTo = 'Giao cho';
$lang->repo->openedDate = 'Ngày tạo';

$lang->repo->latestRevision = 'Latest Revision';
$lang->repo->actionInfo     = "Thêm bởi %s trong %s";
$lang->repo->changes        = "Thay đổi nhật ký";
$lang->repo->reviewLocation = "File: %s@%s, Line: %s - %s";
$lang->repo->commentEdit    = '<i class="icon-pencil"></i>';
$lang->repo->commentDelete  = '<i class="icon-remove"></i>';
$lang->repo->allChanges     = "Thay đổi khác";
$lang->repo->commitTitle    = "The %sth Commit";
$lang->repo->mark           = "Mark Tag";
$lang->repo->split          = "Split Mark";

$lang->repo->objectRule   = 'Object quy tắc';
$lang->repo->objectIdRule = 'Object ID quy tắc';
$lang->repo->actionRule   = 'Action quy tắc';
$lang->repo->manHourRule  = 'Man-hour quy tắc';
$lang->repo->ruleUnit     = "Unit";
$lang->repo->ruleSplit    = "Multiple keywords are divided by ';'. For example: task multiple keywords: Task;task";

$lang->repo->viewDiffList['inline'] = 'Inline';
$lang->repo->viewDiffList['appose'] = 'Parallel';

$lang->repo->encryptList['plain']  = 'Không có encryption';
$lang->repo->encryptList['base64'] = 'BASE64';

$lang->repo->logStyles['A'] = 'Thêm';
$lang->repo->logStyles['M'] = 'Sửa';
$lang->repo->logStyles['D'] = 'Xóa';

$lang->repo->encodingList['utf_8'] = 'UTF-8';
$lang->repo->encodingList['gbk']   = 'GBK';

$lang->repo->scmList['Gitlab']     = 'GitLab';
$lang->repo->scmList['Gitea']      = 'Gitea';
$lang->repo->scmList['Git']        = 'Git';
$lang->repo->scmList['Subversion'] = 'SVN';

$lang->repo->gitlabHost    = 'GitLab Host';
$lang->repo->gitlabToken   = 'GitLab Token';
$lang->repo->gitlabProject = 'Project';

$lang->repo->serviceHost    = 'Host';
$lang->repo->serviceProject = 'Project';

$lang->repo->placeholder = new stdclass;
$lang->repo->placeholder->gitlabHost = 'Input url of gitlab';

$lang->repo->notice = new stdclass();
$lang->repo->notice->syncing        = 'Đang đồng bộ. Vui lòng đợi ...';
$lang->repo->notice->syncComplete   = 'Synchronized. Now redirecting ...';
$lang->repo->notice->syncedCount    = 'The number of records synchronized is ';
$lang->repo->notice->delete         = 'Bạn có muốn xóa this repo?';
$lang->repo->notice->successDelete  = 'Repository is removed.';
$lang->repo->notice->commentContent = 'Nhận xét';
$lang->repo->notice->deleteReview   = 'Do you want to delete this review?';
$lang->repo->notice->deleteBug      = 'Bạn có muốn xóa bug này?';
$lang->repo->notice->deleteComment  = 'Bạn có muốn xóa this comment?';
$lang->repo->notice->lastSyncTime   = 'Last Sync:';

$lang->repo->rules = new stdclass();
$lang->repo->rules->exampleLabel = "Comment Example";
$lang->repo->rules->example['task']['start']  = "%start% %task% %id%1%split%2 %cost%%consumedmark%1%cunit% %left%%leftmark%3%lunit%";
$lang->repo->rules->example['task']['finish'] = "%finish% %task% %id%1%split%2 %cost%%consumedmark%10%cunit%";
$lang->repo->rules->example['task']['effort'] = "%effort% %task% %id%1%split%2 %cost%%consumedmark%1%cunit% %left%%leftmark%3%lunit%";
$lang->repo->rules->example['bug']['resolve'] = "%resolve% %bug% %id%1%split%2";

$lang->repo->error = new stdclass();
$lang->repo->error->useless       = 'Your server disabled exec and shell_exec, so it cannot be applied.';
$lang->repo->error->connect       = 'Connection to the repo failed. Vui lòng enter username, password and repo address correctly!';
$lang->repo->error->version       = 'Phiên bản 1.8+ of https and svn protocol là bắt buộc. Vui lòng update to latest version! Go to http://subversion.apache.org/';
$lang->repo->error->path          = 'Repo address is the file path, ví dụ:  /home/test.';
$lang->repo->error->cmd           = 'Client Error!';
$lang->repo->error->diff          = 'Two versions phải là selected.';
$lang->repo->error->safe          = 'For security reasons, the client version needs to be detected. Please write the version to the file %s. <br /> Execute command: %s';
$lang->repo->error->product       = "Please select {$lang->productCommon}!";
$lang->repo->error->commentText   = 'Vui lòng nhập nội dung để duyệt!';
$lang->repo->error->comment       = 'Vui lòng nhập content!';
$lang->repo->error->title         = 'Vui lòng nhập title!';
$lang->repo->error->accessDenied  = 'You do not have the privilege to access the repository.';
$lang->repo->error->noFound       = 'The repo không là found.';
$lang->repo->error->noFile        = '%s không tồn tại.';
$lang->repo->error->noPriv        = 'The program does not have the privilege  to switch to %s';
$lang->repo->error->output        = "The command is: %s\nThe error is(%s): %s\n";
$lang->repo->error->clientVersion = "Client version is too low, please upgrade or change SVN client";
$lang->repo->error->encoding      = "The encoding maybe wrong. Vui lòng change the encoding and try again.";
$lang->repo->error->deleted       = "Deletion of the repository failed. The current repository has a commit record associated with the design.";
$lang->repo->error->linkedJob     = "Deletion of the repository failed. The current repository has associated with the Compile.";
$lang->repo->error->clientPath    = "The client installation directory cannot have spaces!";
$lang->repo->error->notFound      = "The repository %s’s URL %s does not exist. Please confirm if this repository has been deleted from the local server.";
$lang->repo->error->noWritable    = '%s is not writable! Please check the privilege, or download will not be done.';
$lang->repo->error->noCloneAddr   = 'The repository clone address was not found';

$lang->repo->syncTips          = '<strong>Bạn có thể tìm tham khảo làm sao thiết lập đồng bộ Git từ <a target="_blank" href="https://www.zentao.pm/book/zentaomanual/free-open-source-project-management-software-git-105.html">here</a>.</strong>';
$lang->repo->encodingsTips     = "The encodings of commit comments, can be comma separated values，ví dụ:  utf-8";
$lang->repo->pathTipsForGitlab = "GitLab Project URL";

$lang->repo->example              = new stdclass();
$lang->repo->example->client      = new stdclass();
$lang->repo->example->path        = new stdclass();
$lang->repo->example->client->git = "ví dụ:  /usr/bin/git";
$lang->repo->example->client->svn = "ví dụ:  /usr/bin/svn";
$lang->repo->example->path->git   = "ví dụ:  /home/user/myproject";
$lang->repo->example->path->svn   = "ví dụ:  http://example.googlecode.com/svn/trunk/myproject";
$lang->repo->example->config      = "Config directory là bắt buộc in https. Sử dụng '--config-dir' to generate config dir.";
$lang->repo->example->encoding    = "input encoding of files";

$lang->repo->typeList['standard']    = 'Tiêu chuẩn';
$lang->repo->typeList['performance'] = 'Hiệu suất';
$lang->repo->typeList['security']    = 'Bảo mật';
$lang->repo->typeList['redundancy']  = 'Redundancy';
$lang->repo->typeList['logicError']  = 'Logic Error';
